@@ -1,6 +1,6 @@
 """
 Python interface for TeVCat (http://tevcat.uchicago.edu/)
-$Id: tevcat_all.py 9 2011-12-27 03:08:05Z oxon $
+$Id: tevcat_all.py 15 2012-09-26 07:46:26Z oxon $
 """
 
 import urllib
@@ -21,7 +21,7 @@ source_type_names = ('', 'HBL', '', '', '',
                      '', 'Shell', 'Starburst', 'UNID', '',
                      '', 'XRB', 'Cat. Var.', '', 'FSRQ',
                      'IBL', '', 'Gamma BIN', '', 'SNR/Molec. Cloud',
-                     'Massive Star Cluster', 'AGN (unknown type)', 'Star Forming Region', '', '')
+                     'Massive Star Cluster', 'AGN (unknown type)', 'Star Forming Region', 'Globular Cluster', '')
 
 class TeVCat(object):
     def __init__(self):
